@@ -26,9 +26,12 @@
 #define _POSIX_C_SOURCE 200112L /* for fdopen() */
 
 #include <config.h>
+#include "common.h"
 #include "util.h"
 #include "main.h"
 
+#include <clutter/clutter.h> /* For clutter_threads_add_repaint_func() */
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -37,7 +40,12 @@
 #include <X11/Xlib.h>   /* must explicitly be included for Solaris; #326746 */
 #include <X11/Xutil.h>  /* Just for the definition of the various gravities */
 
-MetaNexus *sigchld_nexus;
+#ifdef WITH_VERBOSE_MODE
+static void
+meta_topic_real_valist (MetaDebugTopic topic,
+                        const char    *format,
+                        va_list        args);
+#endif
 
 #ifdef HAVE_BACKTRACE
 #include <execinfo.h>
@@ -70,7 +78,7 @@ meta_print_backtrace (void)
 }
 #endif
 
-static gboolean is_verbose = FALSE;
+static gint verbose_topics = 0;
 static gboolean is_debugging = FALSE;
 static gboolean replace_current = FALSE;
 static int no_prefix = 0;
@@ -127,7 +135,7 @@ ensure_logfile (void)
 gboolean
 meta_is_verbose (void)
 {
-  return is_verbose;
+  return verbose_topics != 0;
 }
 
 void
@@ -140,8 +148,48 @@ meta_set_verbose (gboolean setting)
   if (setting)
     ensure_logfile ();
 #endif
-  
-  is_verbose = setting;
+
+  if (setting)
+    meta_add_verbose_topic (META_DEBUG_VERBOSE);
+  else
+    meta_remove_verbose_topic (META_DEBUG_VERBOSE);
+}
+
+/**
+ * meta_add_verbose_topic:
+ * @topic: Topic for which logging will be started
+ *
+ * Ensure log messages for the given topic @topic
+ * will be printed.
+ */
+void
+meta_add_verbose_topic (MetaDebugTopic topic)
+{
+  if (verbose_topics == META_DEBUG_VERBOSE)
+    return;
+  if (topic == META_DEBUG_VERBOSE)
+    verbose_topics = META_DEBUG_VERBOSE;
+  else
+    verbose_topics |= topic;
+}
+
+/**
+ * meta_remove_verbose_topic:
+ * @topic: Topic for which logging will be stopped
+ *
+ * Stop printing log messages for the given topic @topic.  Note
+ * that this method does not stack with meta_add_verbose_topic();
+ * i.e. if two calls to meta_add_verbose_topic() for the same
+ * topic are made, one call to meta_remove_verbose_topic() will
+ * remove it.
+ */
+void
+meta_remove_verbose_topic (MetaDebugTopic topic)
+{
+  if (topic == META_DEBUG_VERBOSE)
+    verbose_topics = 0;
+  else
+    verbose_topics &= ~topic;
 }
 
 gboolean
@@ -249,27 +297,10 @@ void
 meta_verbose_real (const char *format, ...)
 {
   va_list args;
-  gchar *str;
-  FILE *out;
 
-  g_return_if_fail (format != NULL);
-
-  if (!is_verbose)
-    return;
-  
   va_start (args, format);
-  str = g_strdup_vprintf (format, args);
+  meta_topic_real_valist (META_DEBUG_VERBOSE, format, args);
   va_end (args);
-
-  out = logfile ? logfile : stderr;
-  
-  if (no_prefix == 0)
-    utf8_fputs ("Window manager: ", out);
-  utf8_fputs (str, out);
-
-  fflush (out);
-  
-  g_free (str);
 }
 #endif /* WITH_VERBOSE_MODE */
 
@@ -323,6 +354,8 @@ topic_name (MetaDebugTopic topic)
       return "COMPOSITOR";
     case META_DEBUG_EDGE_RESISTANCE:
       return "EDGE_RESISTANCE";
+    case META_DEBUG_VERBOSE:
+      return "VERBOSE";
     }
 
   return "WM";
@@ -330,23 +363,22 @@ topic_name (MetaDebugTopic topic)
 
 static int sync_count = 0;
 
-void
-meta_topic_real (MetaDebugTopic topic,
-                 const char *format,
-                 ...)
+static void
+meta_topic_real_valist (MetaDebugTopic topic,
+                        const char    *format,
+                        va_list        args)
 {
-  va_list args;
   gchar *str;
   FILE *out;
 
   g_return_if_fail (format != NULL);
 
-  if (!is_verbose)
+  if (verbose_topics == 0
+      || (topic == META_DEBUG_VERBOSE && verbose_topics != META_DEBUG_VERBOSE)
+      || (!(verbose_topics & topic)))
     return;
-  
-  va_start (args, format);  
+
   str = g_strdup_vprintf (format, args);
-  va_end (args);
 
   out = logfile ? logfile : stderr;
 
@@ -365,6 +397,18 @@ meta_topic_real (MetaDebugTopic topic,
   
   g_free (str);
 }
+
+void
+meta_topic_real (MetaDebugTopic topic,
+                 const char *format,
+                 ...)
+{
+  va_list args;
+
+  va_start (args, format);
+  meta_topic_real_valist (topic, format, args);
+  va_end (args);
+}
 #endif /* WITH_VERBOSE_MODE */
 
 void
@@ -557,7 +601,7 @@ meta_show_dialog (const char *type,
   int i=0;
   GPid child_pid;
   const char **argvl = g_malloc(sizeof (char*) *
-                                (15 +
+                                (17 +
                                  g_slist_length (columns)*2 +
                                  g_slist_length (entries)));
 
@@ -565,6 +609,8 @@ meta_show_dialog (const char *type,
   argvl[i++] = type;
   argvl[i++] = "--screen";
   argvl[i++] = screen_number_text;
+  argvl[i++] = "--class";
+  argvl[i++] = "mutter-dialog";
   argvl[i++] = "--title";
   /* Translators: This is the title used on dialog boxes */
   argvl[i++] = _("Mutter");
@@ -638,29 +684,200 @@ meta_show_dialog (const char *type,
   return child_pid;
 }
 
-GType
-meta_nexus_get_type (void)
+/***************************************************************************
+ * Later functions: like idles but integrated with the Clutter repaint loop
+ ***************************************************************************/
+
+static guint last_later_id = 0;
+
+typedef struct
 {
-  static GType nexus_type = 0;
+  guint id;
+  MetaLaterType when;
+  GSourceFunc func;
+  gpointer data;
+  GDestroyNotify notify;
+  int source;
+  gboolean run_once;
+} MetaLater;
 
-  if (!nexus_type)
+static GSList *laters = NULL;
+/* This is a dummy timeline used to get the Clutter master clock running */
+static ClutterTimeline *later_timeline;
+static guint later_repaint_func = 0;
+
+static void ensure_later_repaint_func (void);
+
+static void
+destroy_later (MetaLater *later)
+{
+  if (later->source)
+    g_source_remove (later->source);
+  if (later->notify)
+    later->notify (later->data);
+  g_slice_free (MetaLater, later);
+}
+
+/* Used to sort the list of laters with the highest priority
+ * functions first.
+ */
+static int
+compare_laters (gconstpointer a,
+                gconstpointer b)
+{
+  return ((const MetaLater *)a)->when - ((const MetaLater *)b)->when;
+}
+
+static gboolean
+run_repaint_laters (gpointer data)
+{
+  GSList *old_laters = laters;
+  GSList *l;
+  gboolean keep_timeline_running = FALSE;
+  laters = NULL;
+
+  for (l = old_laters; l; l = l->next)
     {
-      static const GTypeInfo nexus_info =
-      {
-        sizeof (MetaNexusClass),
-	NULL, NULL, NULL, NULL, NULL,
-	sizeof (MetaNexus),
-	0,
-	NULL, NULL
-      };
-
-      nexus_type = g_type_register_static (G_TYPE_OBJECT,
-					   "MetaNexus",
-					   &nexus_info,
-					   0);
+      MetaLater *later = l->data;
+      if (later->source == 0 ||
+          (later->when <= META_LATER_BEFORE_REDRAW && !later->run_once))
+        {
+          if (later->func (later->data))
+            {
+              if (later->source == 0)
+                keep_timeline_running = TRUE;
+              laters = g_slist_insert_sorted (laters, later, compare_laters);
+            }
+          else
+            destroy_later (later);
+        }
+      else
+        laters = g_slist_insert_sorted (laters, later, compare_laters);
     }
 
-  return nexus_type;
+  if (!keep_timeline_running)
+    clutter_timeline_stop (later_timeline);
+
+  g_slist_free (old_laters);
+
+  /* Just keep the repaint func around - it's cheap if the list is empty */
+  return TRUE;
+}
+
+static void
+ensure_later_repaint_func (void)
+{
+  if (!later_timeline)
+    later_timeline = clutter_timeline_new (G_MAXUINT);
+
+  if (later_repaint_func == 0)
+    later_repaint_func = clutter_threads_add_repaint_func (run_repaint_laters,
+                                                           NULL, NULL);
+
+  /* Make sure the repaint function gets run */
+  clutter_timeline_start (later_timeline);
+}
+
+static gboolean
+call_idle_later (gpointer data)
+{
+  MetaLater *later = data;
+
+  if (!later->func (later->data))
+    {
+      laters = g_slist_remove (laters, later);
+      later->source = 0;
+      destroy_later (later);
+      return FALSE;
+    }
+  else
+    {
+      later->run_once = TRUE;
+      return TRUE;
+    }
+}
+
+/**
+ * meta_later_add:
+ * @when:     enumeration value determining the phase at which to run the callback
+ * @func:     callback to run later
+ * @data:     data to pass to the callback
+ * @notify:   function to call to destroy @data when it is no longer in use, or %NULL
+ *
+ * Sets up a callback  to be called at some later time. @when determines the
+ * particular later occasion at which it is called. This is much like g_idle_add(),
+ * except that the functions interact properly with clutter event handling.
+ * If a "later" function is added from a clutter event handler, and is supposed
+ * to be run before the stage is redrawn, it will be run before that redraw
+ * of the stage, not the next one.
+ *
+ * Return value: an integer ID (guaranteed to be non-zero) that can be used
+ *  to cancel the callback and prevent it from being run.
+ */
+guint
+meta_later_add (MetaLaterType  when,
+                GSourceFunc    func,
+                gpointer       data,
+                GDestroyNotify notify)
+{
+  MetaLater *later = g_slice_new0 (MetaLater);
+
+  later->id = ++last_later_id;
+  later->when = when;
+  later->func = func;
+  later->data = data;
+  later->notify = notify;
+
+  laters = g_slist_insert_sorted (laters, later, compare_laters);
+
+  switch (when)
+    {
+    case META_LATER_RESIZE:
+      /* We add this one two ways - as a high-priority idle and as a
+       * repaint func. If we are in a clutter event callback, the repaint
+       * handler will get hit first, and we'll take care of this function
+       * there so it gets called before the stage is redrawn, even if
+       * we haven't gotten back to the main loop. Otherwise, the idle
+       * handler will get hit first and we want to call this function
+       * there so it will happen before GTK+ repaints.
+       */
+      later->source = g_idle_add_full (META_PRIORITY_RESIZE, call_idle_later, later, NULL);
+      ensure_later_repaint_func ();
+      break;
+    case META_LATER_BEFORE_REDRAW:
+      ensure_later_repaint_func ();
+      break;
+    case META_LATER_IDLE:
+      later->source = g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, call_idle_later, later, NULL);
+      break;
+    }
+
+  return later->id;
+}
+
+/**
+ * meta_later_remove:
+ * @later_id: the integer ID returned from meta_later_add()
+ *
+ * Removes a callback added with meta_later_add()
+ */
+void
+meta_later_remove (guint later_id)
+{
+  GSList *l;
+
+  for (l = laters; l; l = l->next)
+    {
+      MetaLater *later = l->data;
+      if (later->id == later_id)
+        {
+          laters = g_slist_remove_link (laters, l);
+          /* If this was a "repaint func" later, we just let the
+           * repaint func run and get removed
+           */
+          destroy_later (later);
+        }
+    }
 }
 
 /* eof util.c */
