@@ -30,13 +30,13 @@
 
 #include "types.h"
 #include "compositor.h"
-#include "mutter-window.h"
+#include "meta-window-actor.h"
 
 /* Public compositor API */
-ClutterActor * mutter_get_stage_for_screen (MetaScreen *screen);
-ClutterActor * mutter_get_overlay_group_for_screen (MetaScreen *screen);
-Window         mutter_get_overlay_window (MetaScreen *screen);
-GList        * mutter_get_windows (MetaScreen *screen);
-ClutterActor * mutter_get_window_group_for_screen (MetaScreen *screen);
+ClutterActor *meta_get_stage_for_screen         (MetaScreen *screen);
+ClutterActor *meta_get_overlay_group_for_screen (MetaScreen *screen);
+Window        meta_get_overlay_window           (MetaScreen *screen);
+GList        *meta_get_window_actors            (MetaScreen *screen);
+ClutterActor *meta_get_window_group_for_screen  (MetaScreen *screen);
 
 #endif
